@@ -15,6 +15,11 @@ class Keyring(KeyringBackend):
     priority = 0
 
     def get_password(self, service, username, password=None):
-        raise RuntimeError("No recommended backend was available")
+        msg = (
+            "No recommended backend was available. Install the "
+            "keyrings.alt package if you want to use the non-"
+            "recommended backends. See README.rst for details."
+        )
+        raise RuntimeError(msg)
 
     set_password = delete_pasword = get_password
